Class: Zavudev::Models::CallListResponse::Transcript

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/zavudev/models/call_list_response.rb,
sig/zavudev/models/call_list_response.rbs

Defined Under Namespace

Modules: Role

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(role:, seq:, text:, ended_at: nil, started_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Zavudev::Models::CallListResponse::Transcript for more details.

A single turn in a voice call transcript.

Parameters:

  • role (Symbol, Zavudev::Models::CallListResponse::Transcript::Role) —

    Who produced the turn. tool records a tool call the agent made during the conv

  • seq (Integer) —

    Ordinal position of the turn within the call, starting at 0.

  • text (String) —

    Transcribed speech for user and assistant turns, or a JSON summary of the to

  • ended_at (Time, nil) (defaults to: nil) —

    When the turn ended.

  • started_at (Time, nil) (defaults to: nil) —

    When the turn started.



# File 'lib/zavudev/models/call_list_response.rb', line 218

Instance Attribute Details

#ended_at ⇒ Time?

When the turn ended.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


210
# File 'lib/zavudev/models/call_list_response.rb', line 210

optional :ended_at, Time, api_name: :endedAt, nil?: true

#role ⇒ Symbol, Zavudev::Models::CallListResponse::Transcript::Role

Who produced the turn. tool records a tool call the agent made during the conversation.

Parameters:

  • value (Zavudev::Models::CallListResponse::Transcript::role)

Returns:



191
# File 'lib/zavudev/models/call_list_response.rb', line 191

required :role, enum: -> { Zavudev::Models::CallListResponse::Transcript::Role }

#seq ⇒ Integer

Ordinal position of the turn within the call, starting at 0.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


197
# File 'lib/zavudev/models/call_list_response.rb', line 197

required :seq, Integer

#started_at ⇒ Time?

When the turn started.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


216
# File 'lib/zavudev/models/call_list_response.rb', line 216

optional :started_at, Time, api_name: :startedAt, nil?: true

#text ⇒ String

Transcribed speech for user and assistant turns, or a JSON summary of the tool call for tool turns.

Parameters:

  • value (String)

Returns:

  • (String)


204
# File 'lib/zavudev/models/call_list_response.rb', line 204

required :text, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


161
# File 'sig/zavudev/models/call_list_response.rbs', line 161

def to_hash: -> {