Class: Zavudev::Models::ContactUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/zavudev/models/contact_update_params.rb,
sig/zavudev/models/contact_update_params.rbs

Overview

See Also:

  • Zavudev::Resources::Contacts#update

Defined Under Namespace

Modules: DefaultChannel

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(contact_id:, default_channel: nil, display_name: nil, metadata: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Zavudev::Models::ContactUpdateParams for more details.

Parameters:

  • contact_id (String)
  • default_channel (Symbol, Zavudev::Models::ContactUpdateParams::DefaultChannel, nil) (defaults to: nil) —

    Preferred channel for this contact. Set to null to clear.

  • display_name (String, nil) (defaults to: nil) —

    Human-readable name for this contact. Set to null to clear it and fall back to t

  • metadata (Hash{Symbol=>String}) (defaults to: nil)
  • request_options (Zavudev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/zavudev/models/contact_update_params.rb', line 37

Instance Attribute Details

#contact_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/zavudev/models/contact_update_params.rb', line 13

required :contact_id, String

#default_channel ⇒ Symbol, ...

Preferred channel for this contact. Set to null to clear.

Parameters:

  • value (Zavudev::Models::ContactUpdateParams::default_channel, nil)

Returns:



19
20
21
22
# File 'lib/zavudev/models/contact_update_params.rb', line 19

optional :default_channel,
enum: -> { Zavudev::ContactUpdateParams::DefaultChannel },
api_name: :defaultChannel,
nil?: true

#display_name ⇒ String?

Human-readable name for this contact. Set to null to clear it and fall back to the contact's identifier. Contacts created automatically from an inbound message have no display name until you set one.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


30
# File 'lib/zavudev/models/contact_update_params.rb', line 30

optional :display_name, String, api_name: :displayName, nil?: true

#metadata ⇒ Hash{Symbol=>String}?

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


35
# File 'lib/zavudev/models/contact_update_params.rb', line 35

optional :metadata, Zavudev::Internal::Type::HashOf[String]

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


34
# File 'sig/zavudev/models/contact_update_params.rbs', line 34

def to_hash: -> {