Class: Zavudev::Models::Contacts::ChannelAddParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/zavudev/models/contacts/channel_add_params.rb

Overview

Defined Under Namespace

Modules: Channel

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(contact_id:, channel:, identifier:, country_code: nil, is_primary: nil, label: nil, request_options: {}) ⇒ Object

Parameters:

  • contact_id (String)
  • channel (Symbol, Zavudev::Models::Contacts::ChannelAddParams::Channel)

    Channel type.

  • identifier (String)

    Channel identifier (phone number in E.164 format or email address).

  • country_code (String) (defaults to: nil)

    ISO country code for phone numbers.

  • is_primary (Boolean) (defaults to: nil)

    Whether this should be the primary channel for its type.

  • label (String) (defaults to: nil)

    Optional label for the channel.

  • request_options (Zavudev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 46

Instance Attribute Details

#channelSymbol, Zavudev::Models::Contacts::ChannelAddParams::Channel

Channel type.



20
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 20

required :channel, enum: -> { Zavudev::Contacts::ChannelAddParams::Channel }

#contact_idString

Returns:

  • (String)


14
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 14

required :contact_id, String

#country_codeString?

ISO country code for phone numbers.

Returns:

  • (String, nil)


32
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 32

optional :country_code, String, api_name: :countryCode

#identifierString

Channel identifier (phone number in E.164 format or email address).

Returns:

  • (String)


26
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 26

required :identifier, String

#is_primaryBoolean?

Whether this should be the primary channel for its type.

Returns:

  • (Boolean, nil)


38
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 38

optional :is_primary, Zavudev::Internal::Type::Boolean, api_name: :isPrimary

#labelString?

Optional label for the channel.

Returns:

  • (String, nil)


44
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 44

optional :label, String