Class: Zavudev::Models::ConversationMarkAsReadResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::ConversationMarkAsReadResponse
- Defined in:
- lib/zavudev/models/conversation_mark_as_read_response.rb,
sig/zavudev/models/conversation_mark_as_read_response.rbs
Overview
Defined Under Namespace
Classes: Conversation
Instance Attribute Summary collapse
-
#conversation ⇒ Zavudev::Models::ConversationMarkAsReadResponse::Conversation
An inbox thread with one contact.
Instance Method Summary collapse
-
#initialize(conversation:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConversationMarkAsReadResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(conversation:) ⇒ Object
Some parameter documentations has been truncated, see Zavudev::Models::ConversationMarkAsReadResponse for more details.
|
|
# File 'lib/zavudev/models/conversation_mark_as_read_response.rb', line 15
|
Instance Attribute Details
#conversation ⇒ Zavudev::Models::ConversationMarkAsReadResponse::Conversation
An inbox thread with one contact. A conversation groups every message exchanged with that contact across channels, so a contact who writes on WhatsApp and later by email stays in one thread.
13 |
# File 'lib/zavudev/models/conversation_mark_as_read_response.rb', line 13 required :conversation, -> { Zavudev::Models::ConversationMarkAsReadResponse::Conversation } |
Instance Method Details
#to_hash ⇒ {
15 |
# File 'sig/zavudev/models/conversation_mark_as_read_response.rbs', line 15
def to_hash: -> {
|