Class: Zavudev::Models::FunctionTailLogsParams
Overview
Instance Attribute Summary collapse
#request_options
Instance Method Summary
collapse
dump_request
included
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(function_id:, end_time: nil, filter_pattern: nil, limit: nil, next_token: nil, start_time: nil, request_options: {}) ⇒ Object
|
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 42
|
Instance Attribute Details
#end_time ⇒ Integer?
End of the log window in Unix epoch milliseconds.
19
|
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 19
optional :end_time, Integer
|
#filter_pattern ⇒ String?
24
|
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 24
optional :filter_pattern, String
|
#function_id ⇒ String
13
|
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 13
required :function_id, String
|
#limit ⇒ Integer?
29
|
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 29
optional :limit, Integer
|
#next_token ⇒ String?
34
|
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 34
optional :next_token, String
|
#start_time ⇒ Integer?
Start of the log window in Unix epoch milliseconds.
40
|
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 40
optional :start_time, Integer
|
Instance Method Details
#to_hash ⇒ {
50
|
# File 'sig/zavudev/models/function_tail_logs_params.rbs', line 50
def to_hash: -> {
|