Class: Zavudev::Models::FunctionTailLogsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::FunctionTailLogsResponse
- Defined in:
- lib/zavudev/models/function_tail_logs_response.rb
Overview
Defined Under Namespace
Classes: Event
Instance Attribute Summary collapse
- #events ⇒ Array<Zavudev::Models::FunctionTailLogsResponse::Event>
-
#next_token ⇒ String?
Pass to the next request to fetch the following page of logs.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Zavudev::Internal::Type::BaseModel
Instance Attribute Details
#events ⇒ Array<Zavudev::Models::FunctionTailLogsResponse::Event>
10 11 |
# File 'lib/zavudev/models/function_tail_logs_response.rb', line 10 required :events, -> { Zavudev::Internal::Type::ArrayOf[Zavudev::Models::FunctionTailLogsResponse::Event] } |
#next_token ⇒ String?
Pass to the next request to fetch the following page of logs.
17 |
# File 'lib/zavudev/models/function_tail_logs_response.rb', line 17 optional :next_token, String, api_name: :nextToken, nil?: true |