Class: Zavudev::Models::IntrospectValidatePhoneResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/zavudev/models/introspect_validate_phone_response.rb

Overview

Defined Under Namespace

Classes: Carrier

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country_code:, phone_number:, valid_number:, available_channels: nil, carrier: nil, line_type: nil, national_format: nil) ⇒ Object

Parameters:

  • country_code (String)
  • phone_number (String)
  • valid_number (Boolean)
  • available_channels (Array<String>) (defaults to: nil)

    List of available messaging channels for this phone number.

  • carrier (Zavudev::Models::IntrospectValidatePhoneResponse::Carrier) (defaults to: nil)

    Carrier information for the phone number.

  • line_type (Symbol, Zavudev::Models::LineType) (defaults to: nil)

    Type of phone line.

  • national_format (String) (defaults to: nil)

    Phone number in national format.



# File 'lib/zavudev/models/introspect_validate_phone_response.rb', line 46

Instance Attribute Details

#available_channelsArray<String>?

List of available messaging channels for this phone number.

Returns:

  • (Array<String>, nil)


26
# File 'lib/zavudev/models/introspect_validate_phone_response.rb', line 26

optional :available_channels, Zavudev::Internal::Type::ArrayOf[String], api_name: :availableChannels

#carrierZavudev::Models::IntrospectValidatePhoneResponse::Carrier?

Carrier information for the phone number.



32
# File 'lib/zavudev/models/introspect_validate_phone_response.rb', line 32

optional :carrier, -> { Zavudev::Models::IntrospectValidatePhoneResponse::Carrier }

#country_codeString

Returns:

  • (String)


10
# File 'lib/zavudev/models/introspect_validate_phone_response.rb', line 10

required :country_code, String, api_name: :countryCode

#line_typeSymbol, ...

Type of phone line.

Returns:



38
# File 'lib/zavudev/models/introspect_validate_phone_response.rb', line 38

optional :line_type, enum: -> { Zavudev::LineType }, api_name: :lineType

#national_formatString?

Phone number in national format.

Returns:

  • (String, nil)


44
# File 'lib/zavudev/models/introspect_validate_phone_response.rb', line 44

optional :national_format, String, api_name: :nationalFormat

#phone_numberString

Returns:

  • (String)


15
# File 'lib/zavudev/models/introspect_validate_phone_response.rb', line 15

required :phone_number, String, api_name: :phoneNumber

#valid_numberBoolean

Returns:

  • (Boolean)


20
# File 'lib/zavudev/models/introspect_validate_phone_response.rb', line 20

required :valid_number, Zavudev::Internal::Type::Boolean, api_name: :validNumber