Class: Zavudev::Models::InvitationListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::InvitationListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/zavudev/models/invitation_list_params.rb,
sig/zavudev/models/invitation_list_params.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
- #cursor ⇒ String?
- #limit ⇒ Integer?
-
#status ⇒ Symbol, ...
Current status of the partner invitation.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(cursor: nil, limit: nil, status: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see InvitationListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cursor: nil, limit: nil, status: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Zavudev::Models::InvitationListParams for more details.
|
|
# File 'lib/zavudev/models/invitation_list_params.rb', line 31
|
Instance Attribute Details
#cursor ⇒ String?
13 |
# File 'lib/zavudev/models/invitation_list_params.rb', line 13 optional :cursor, String |
#limit ⇒ Integer?
18 |
# File 'lib/zavudev/models/invitation_list_params.rb', line 18 optional :limit, Integer |
#status ⇒ Symbol, ...
Current status of the partner invitation.
failed means the client started the connection and it did not finish (they
cancelled Meta's dialog, denied a permission, or abandoned the tab). A failed
invitation is still usable: the same link can be retried, and it moves back to
in_progress when the client tries again.
29 |
# File 'lib/zavudev/models/invitation_list_params.rb', line 29 optional :status, enum: -> { Zavudev::InvitationListParams::Status } |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/zavudev/models/invitation_list_params.rbs', line 36
def to_hash: -> {
|