Class: Zavudev::Models::PhoneNumberPricing
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::PhoneNumberPricing
- Defined in:
- lib/zavudev/models/phone_number_pricing.rb,
sig/zavudev/models/phone_number_pricing.rbs
Instance Attribute Summary collapse
-
#is_free_eligible ⇒ Boolean?
Whether this number qualifies for the free first US number offer.
-
#monthly_price ⇒ Float?
Monthly price in USD.
-
#upfront_price ⇒ Float?
One-time purchase price in USD.
Instance Method Summary collapse
- #initialize(is_free_eligible: nil, monthly_price: nil, upfront_price: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(is_free_eligible: nil, monthly_price: nil, upfront_price: nil) ⇒ Object
|
|
# File 'lib/zavudev/models/phone_number_pricing.rb', line 24
|
Instance Attribute Details
#is_free_eligible ⇒ Boolean?
Whether this number qualifies for the free first US number offer.
10 |
# File 'lib/zavudev/models/phone_number_pricing.rb', line 10 optional :is_free_eligible, Zavudev::Internal::Type::Boolean, api_name: :isFreeEligible |
#monthly_price ⇒ Float?
Monthly price in USD.
16 |
# File 'lib/zavudev/models/phone_number_pricing.rb', line 16 optional :monthly_price, Float, api_name: :monthlyPrice |
#upfront_price ⇒ Float?
One-time purchase price in USD.
22 |
# File 'lib/zavudev/models/phone_number_pricing.rb', line 22 optional :upfront_price, Float, api_name: :upfrontPrice |
Instance Method Details
#to_hash ⇒ {
25 |
# File 'sig/zavudev/models/phone_number_pricing.rbs', line 25
def to_hash: -> {
|