Module: Zavudev::Models::PhoneNumberType

Extended by:
Internal::Type::Enum
Defined in:
lib/zavudev/models/phone_number_type.rb,
sig/zavudev/models/phone_number_type.rbs

Overview

Type of phone number. mobile is stocked in countries where no geographic (local) or non-geographic (national) inventory exists, and in several markets it is the only type that can receive SMS.

Constant Summary collapse

LOCAL =

Returns:

  • (:local)
:local
NATIONAL =

Returns:

  • (:national)
:national
TOLL_FREE =

Returns:

  • (:tollFree)
:tollFree
MOBILE =

Returns:

  • (:mobile)
:mobile

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/zavudev/models/phone_number_type.rb', line 16


Instance Method Details

#self?.values ⇒ ::Array[Zavudev::Models::phone_number_type]

Returns:

  • (::Array[Zavudev::Models::phone_number_type])


13
# File 'sig/zavudev/models/phone_number_type.rbs', line 13

def self?.values: -> ::Array[Zavudev::Models::phone_number_type]