Class: Zavudev::Models::TemplateSubmitParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/zavudev/models/template_submit_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(template_id:, sender_id:, category: nil, request_options: {}) ⇒ Object

Parameters:

  • template_id (String)
  • sender_id (String)

    The sender ID with the WhatsApp Business Account to submit the template to.

  • category (Symbol, Zavudev::Models::WhatsappCategory) (defaults to: nil)

    Template category. If not provided, uses the category set on the template.

  • request_options (Zavudev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/zavudev/models/template_submit_params.rb', line 27

Instance Attribute Details

#categorySymbol, ...

Template category. If not provided, uses the category set on the template.

Returns:



25
# File 'lib/zavudev/models/template_submit_params.rb', line 25

optional :category, enum: -> { Zavudev::WhatsappCategory }

#sender_idString

The sender ID with the WhatsApp Business Account to submit the template to.

Returns:

  • (String)


19
# File 'lib/zavudev/models/template_submit_params.rb', line 19

required :sender_id, String, api_name: :senderId

#template_idString

Returns:

  • (String)


13
# File 'lib/zavudev/models/template_submit_params.rb', line 13

required :template_id, String