Class: Zavudev::Models::TemplateSyncResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/zavudev/models/template_sync_response.rb,
sig/zavudev/models/template_sync_response.rbs

Overview

See Also:

  • Zavudev::Resources::Templates#sync

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accounts_synced:, errors:, imported:, linked:, skipped:, updated:) ⇒ Object

Some parameter documentations has been truncated, see Zavudev::Models::TemplateSyncResponse for more details.

Parameters:

  • accounts_synced (Integer) —

    WhatsApp Business Accounts reconciled in this call.

  • errors (Array<String>) —

    Problems hit while syncing. Non-empty with a 200 means part of the sync did not

  • imported (Integer) —

    Templates that existed on Meta and were created in Zavu by this call.

  • linked (Integer) —

    Existing Zavu templates that were matched to a Meta template by name and bound t

  • skipped (Integer) —

    Meta templates left alone: already linked to a Zavu template, or rejected/disabl

  • updated (Integer) —

    Templates whose approval status changed to match Meta.



# File 'lib/zavudev/models/template_sync_response.rb', line 46


Instance Attribute Details

#accounts_synced ⇒ Integer

WhatsApp Business Accounts reconciled in this call.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11
# File 'lib/zavudev/models/template_sync_response.rb', line 11

required :accounts_synced, Integer, api_name: :accountsSynced

#errors ⇒ Array<String>

Problems hit while syncing. Non-empty with a 200 means part of the sync did not complete — the rest still did.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


18
# File 'lib/zavudev/models/template_sync_response.rb', line 18

required :errors, Zavudev::Internal::Type::ArrayOf[String]

#imported ⇒ Integer

Templates that existed on Meta and were created in Zavu by this call.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


24
# File 'lib/zavudev/models/template_sync_response.rb', line 24

required :imported, Integer

#linked ⇒ Integer

Existing Zavu templates that were matched to a Meta template by name and bound to its Meta ID.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


31
# File 'lib/zavudev/models/template_sync_response.rb', line 31

required :linked, Integer

#skipped ⇒ Integer

Meta templates left alone: already linked to a Zavu template, or rejected/disabled on Meta.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


38
# File 'lib/zavudev/models/template_sync_response.rb', line 38

required :skipped, Integer

#updated ⇒ Integer

Templates whose approval status changed to match Meta.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


44
# File 'lib/zavudev/models/template_sync_response.rb', line 44

required :updated, Integer

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


35
# File 'sig/zavudev/models/template_sync_response.rbs', line 35

def to_hash: -> {