Class: Zavudev::Resources::Me

Inherits:
Object
  • Object
show all
Defined in:
lib/zavudev/resources/me.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Me

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Me.

Parameters:



28
29
30
# File 'lib/zavudev/resources/me.rb', line 28

def initialize(client:)
  @client = client
end

Instance Method Details

#retrieve(request_options: {}) ⇒ Zavudev::Models::MeRetrieveResponse

Returns the project, team, and API key metadata bound to the current Bearer token. Used by CLIs and SDKs to confirm which project they will operate on.

Parameters:

Returns:

See Also:



16
17
18
19
20
21
22
23
# File 'lib/zavudev/resources/me.rb', line 16

def retrieve(params = {})
  @client.request(
    method: :get,
    path: "v1/me",
    model: Zavudev::Models::MeRetrieveResponse,
    options: params[:request_options]
  )
end