Class: Zavudev::Resources::Plan
- Inherits:
-
Object
- Object
- Zavudev::Resources::Plan
- Defined in:
- lib/zavudev/resources/plan.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ Plan
constructor
private
A new instance of Plan.
-
#retrieve(request_options: {}) ⇒ Zavudev::Models::PlanRetrieveResponse
Get the current subscription plan for the API key’s team, including tier, billing interval, and period dates.
Constructor Details
#initialize(client:) ⇒ Plan
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Plan.
28 29 30 |
# File 'lib/zavudev/resources/plan.rb', line 28 def initialize(client:) @client = client end |
Instance Method Details
#retrieve(request_options: {}) ⇒ Zavudev::Models::PlanRetrieveResponse
Get the current subscription plan for the API key’s team, including tier, billing interval, and period dates.
16 17 18 19 20 21 22 23 |
# File 'lib/zavudev/resources/plan.rb', line 16 def retrieve(params = {}) @client.request( method: :get, path: "v1/plan", model: Zavudev::Models::PlanRetrieveResponse, options: params[:request_options] ) end |