Class: Zavudev::Models::ContactChannel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::ContactChannel
- Defined in:
- lib/zavudev/models/contact_channel.rb
Defined Under Namespace
Modules: Channel Classes: Metrics
Instance Attribute Summary collapse
-
#channel ⇒ Symbol, Zavudev::Models::ContactChannel::Channel
Channel type.
-
#country_code ⇒ String?
ISO country code for phone numbers.
- #created_at ⇒ Time
- #id ⇒ String
-
#identifier ⇒ String
Channel identifier (phone number or email address).
-
#is_primary ⇒ Boolean
Whether this is the primary channel for its type.
-
#label ⇒ String?
Optional label for the channel.
-
#last_inbound_at ⇒ Time?
Last time a message was received on this channel.
- #metadata ⇒ Hash{Symbol=>String}?
-
#metrics ⇒ Zavudev::Models::ContactChannel::Metrics?
Delivery metrics for this channel.
- #updated_at ⇒ Time?
-
#verified ⇒ Boolean
Whether this channel has been verified.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, channel:, created_at:, identifier:, is_primary:, verified:, country_code: nil, label: nil, last_inbound_at: nil, metadata: nil, metrics: nil, updated_at: nil) ⇒ Object
constructor
A communication channel for a contact.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, channel:, created_at:, identifier:, is_primary:, verified:, country_code: nil, label: nil, last_inbound_at: nil, metadata: nil, metrics: nil, updated_at: nil) ⇒ Object
A communication channel for a contact.
|
|
# File 'lib/zavudev/models/contact_channel.rb', line 74
|
Instance Attribute Details
#channel ⇒ Symbol, Zavudev::Models::ContactChannel::Channel
Channel type.
15 |
# File 'lib/zavudev/models/contact_channel.rb', line 15 required :channel, enum: -> { Zavudev::ContactChannel::Channel } |
#country_code ⇒ String?
ISO country code for phone numbers.
44 |
# File 'lib/zavudev/models/contact_channel.rb', line 44 optional :country_code, String, api_name: :countryCode |
#created_at ⇒ Time
20 |
# File 'lib/zavudev/models/contact_channel.rb', line 20 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
9 |
# File 'lib/zavudev/models/contact_channel.rb', line 9 required :id, String |
#identifier ⇒ String
Channel identifier (phone number or email address).
26 |
# File 'lib/zavudev/models/contact_channel.rb', line 26 required :identifier, String |
#is_primary ⇒ Boolean
Whether this is the primary channel for its type.
32 |
# File 'lib/zavudev/models/contact_channel.rb', line 32 required :is_primary, Zavudev::Internal::Type::Boolean, api_name: :isPrimary |
#label ⇒ String?
Optional label for the channel.
50 |
# File 'lib/zavudev/models/contact_channel.rb', line 50 optional :label, String |
#last_inbound_at ⇒ Time?
Last time a message was received on this channel.
56 |
# File 'lib/zavudev/models/contact_channel.rb', line 56 optional :last_inbound_at, Time, api_name: :lastInboundAt |
#metadata ⇒ Hash{Symbol=>String}?
61 |
# File 'lib/zavudev/models/contact_channel.rb', line 61 optional :metadata, Zavudev::Internal::Type::HashOf[String] |
#metrics ⇒ Zavudev::Models::ContactChannel::Metrics?
Delivery metrics for this channel.
67 |
# File 'lib/zavudev/models/contact_channel.rb', line 67 optional :metrics, -> { Zavudev::ContactChannel::Metrics } |
#updated_at ⇒ Time?
72 |
# File 'lib/zavudev/models/contact_channel.rb', line 72 optional :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/zavudev/models/contact_channel.rb', line 113
|