Class: Zavudev::Models::Contacts::ChannelAddParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::Contacts::ChannelAddParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/zavudev/models/contacts/channel_add_params.rb
Overview
Defined Under Namespace
Modules: Channel
Instance Attribute Summary collapse
-
#channel ⇒ Symbol, Zavudev::Models::Contacts::ChannelAddParams::Channel
Channel type.
- #contact_id ⇒ String
-
#country_code ⇒ String?
ISO country code for phone numbers.
-
#identifier ⇒ String
Channel identifier (phone number in E.164 format or email address).
-
#is_primary ⇒ Boolean?
Whether this should be the primary channel for its type.
-
#label ⇒ String?
Optional label for the channel.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contact_id:, channel:, identifier:, country_code: nil, is_primary: nil, label: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 46
|
Instance Attribute Details
#channel ⇒ Symbol, Zavudev::Models::Contacts::ChannelAddParams::Channel
Channel type.
20 |
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 20 required :channel, enum: -> { Zavudev::Contacts::ChannelAddParams::Channel } |
#contact_id ⇒ String
14 |
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 14 required :contact_id, String |
#country_code ⇒ String?
ISO country code for phone numbers.
32 |
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 32 optional :country_code, String, api_name: :countryCode |
#identifier ⇒ String
Channel identifier (phone number in E.164 format or email address).
26 |
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 26 required :identifier, String |
#is_primary ⇒ Boolean?
Whether this should be the primary channel for its type.
38 |
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 38 optional :is_primary, Zavudev::Internal::Type::Boolean, api_name: :isPrimary |
#label ⇒ String?
Optional label for the channel.
44 |
# File 'lib/zavudev/models/contacts/channel_add_params.rb', line 44 optional :label, String |