Class: Zavudev::Models::FunctionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::FunctionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/zavudev/models/function_create_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#dependencies ⇒ Hash{Symbol=>String}?
npm dependencies.
- #description ⇒ String?
-
#http_enabled ⇒ Boolean?
Whether to expose a public HTTPS URL for this function.
- #memory_mb ⇒ Integer, ...
- #name ⇒ String
-
#runtime ⇒ Symbol, ...
Runtime the function is deployed on.
-
#slug ⇒ String
URL-safe identifier (lowercase, digits, hyphens).
-
#source_code ⇒ String?
TypeScript source code for the function entry point (max ~900KB).
- #timeout_sec ⇒ Integer?
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Zavudev::Internal::Type::BaseModel
Instance Attribute Details
#dependencies ⇒ Hash{Symbol=>String}?
npm dependencies. Keys are package names, values are semver ranges.
25 |
# File 'lib/zavudev/models/function_create_params.rb', line 25 optional :dependencies, Zavudev::Internal::Type::HashOf[String] |
#description ⇒ String?
30 |
# File 'lib/zavudev/models/function_create_params.rb', line 30 optional :description, String |
#http_enabled ⇒ Boolean?
Whether to expose a public HTTPS URL for this function.
36 |
# File 'lib/zavudev/models/function_create_params.rb', line 36 optional :http_enabled, Zavudev::Internal::Type::Boolean, api_name: :httpEnabled |
#memory_mb ⇒ Integer, ...
41 |
# File 'lib/zavudev/models/function_create_params.rb', line 41 optional :memory_mb, enum: -> { Zavudev::FunctionCreateParams::MemoryMB }, api_name: :memoryMb |
#name ⇒ String
13 |
# File 'lib/zavudev/models/function_create_params.rb', line 13 required :name, String |
#runtime ⇒ Symbol, ...
Runtime the function is deployed on.
47 |
# File 'lib/zavudev/models/function_create_params.rb', line 47 optional :runtime, enum: -> { Zavudev::FunctionCreateParams::Runtime } |
#slug ⇒ String
URL-safe identifier (lowercase, digits, hyphens). Must be unique per project.
19 |
# File 'lib/zavudev/models/function_create_params.rb', line 19 required :slug, String |
#source_code ⇒ String?
TypeScript source code for the function entry point (max ~900KB).
53 |
# File 'lib/zavudev/models/function_create_params.rb', line 53 optional :source_code, String, api_name: :sourceCode |
#timeout_sec ⇒ Integer?
58 |
# File 'lib/zavudev/models/function_create_params.rb', line 58 optional :timeout_sec, Integer, api_name: :timeoutSec |
Class Method Details
.values ⇒ Array<Integer>
|
|
# File 'lib/zavudev/models/function_create_params.rb', line 89
|