Class: Zavudev::Models::FunctionTailLogsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/zavudev/models/function_tail_logs_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(function_id:, end_time: nil, filter_pattern: nil, limit: nil, next_token: nil, start_time: nil, request_options: {}) ⇒ Object

Parameters:

  • function_id (String)
  • end_time (Integer) (defaults to: nil)

    End of the log window in Unix epoch milliseconds.

  • filter_pattern (String) (defaults to: nil)
  • limit (Integer) (defaults to: nil)
  • next_token (String) (defaults to: nil)
  • start_time (Integer) (defaults to: nil)

    Start of the log window in Unix epoch milliseconds.

  • request_options (Zavudev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/zavudev/models/function_tail_logs_params.rb', line 42

Instance Attribute Details

#end_timeInteger?

End of the log window in Unix epoch milliseconds.

Returns:

  • (Integer, nil)


19
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 19

optional :end_time, Integer

#filter_patternString?

Returns:

  • (String, nil)


24
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 24

optional :filter_pattern, String

#function_idString

Returns:

  • (String)


13
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 13

required :function_id, String

#limitInteger?

Returns:

  • (Integer, nil)


29
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 29

optional :limit, Integer

#next_tokenString?

Returns:

  • (String, nil)


34
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 34

optional :next_token, String

#start_timeInteger?

Start of the log window in Unix epoch milliseconds.

Returns:

  • (Integer, nil)


40
# File 'lib/zavudev/models/function_tail_logs_params.rb', line 40

optional :start_time, Integer