Class: Zavudev::Models::MessageListAttachmentsResponse::Item
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::MessageListAttachmentsResponse::Item
- Defined in:
- lib/zavudev/models/message_list_attachments_response.rb,
sig/zavudev/models/message_list_attachments_response.rbs
Instance Attribute Summary collapse
-
#content_id ⇒ String?
Content-ID for inline attachments (referenced in the HTML body as
cid:<contentId>). - #created_at ⇒ Time
-
#download_url ⇒ String?
Short-lived signed URL to download the attachment bytes.
- #filename ⇒ String
- #id ⇒ String
-
#is_inline ⇒ Boolean
Whether the attachment is inline (embedded in the HTML body) rather than a regular attachment.
-
#mime_type ⇒ String
MIME type of the attachment.
-
#size ⇒ Integer
Size of the attachment in bytes.
Instance Method Summary collapse
-
#initialize(id:, content_id:, created_at:, download_url:, filename:, is_inline:, mime_type:, size:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Item for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, content_id:, created_at:, download_url:, filename:, is_inline:, mime_type:, size:) ⇒ Object
Some parameter documentations has been truncated, see Zavudev::Models::MessageListAttachmentsResponse::Item for more details.
A stored file attachment for an email message (inbound or outbound).
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/zavudev/models/message_list_attachments_response.rb', line 16 class Item < Zavudev::Internal::Type::BaseModel # @!attribute id # # @return [String] required :id, String # @!attribute content_id # Content-ID for inline attachments (referenced in the HTML body as # `cid:<contentId>`). Null for regular attachments. # # @return [String, nil] required :content_id, String, api_name: :contentId, nil?: true # @!attribute created_at # # @return [Time] required :created_at, Time, api_name: :createdAt # @!attribute download_url # Short-lived signed URL to download the attachment bytes. Freshly generated on # each request and expires; do not cache it. Null if the stored file is no longer # available. # # @return [String, nil] required :download_url, String, api_name: :downloadUrl, nil?: true # @!attribute filename # # @return [String] required :filename, String # @!attribute is_inline # Whether the attachment is inline (embedded in the HTML body) rather than a # regular attachment. # # @return [Boolean] required :is_inline, Zavudev::Internal::Type::Boolean, api_name: :isInline # @!attribute mime_type # MIME type of the attachment. # # @return [String] required :mime_type, String, api_name: :mimeType # @!attribute size # Size of the attachment in bytes. # # @return [Integer] required :size, Integer # @!method initialize(id:, content_id:, created_at:, download_url:, filename:, is_inline:, mime_type:, size:) # Some parameter documentations has been truncated, see # {Zavudev::Models::MessageListAttachmentsResponse::Item} for more details. # # A stored file attachment for an email message (inbound or outbound). # # @param id [String] # # @param content_id [String, nil] Content-ID for inline attachments (referenced in the HTML body as `cid:<contentI # # @param created_at [Time] # # @param download_url [String, nil] Short-lived signed URL to download the attachment bytes. Freshly generated on ea # # @param filename [String] # # @param is_inline [Boolean] Whether the attachment is inline (embedded in the HTML body) rather than a regul # # @param mime_type [String] MIME type of the attachment. # # @param size [Integer] Size of the attachment in bytes. end |
Instance Attribute Details
#content_id ⇒ String?
Content-ID for inline attachments (referenced in the HTML body as
cid:<contentId>). Null for regular attachments.
27 |
# File 'lib/zavudev/models/message_list_attachments_response.rb', line 27 required :content_id, String, api_name: :contentId, nil?: true |
#created_at ⇒ Time
32 |
# File 'lib/zavudev/models/message_list_attachments_response.rb', line 32 required :created_at, Time, api_name: :createdAt |
#download_url ⇒ String?
Short-lived signed URL to download the attachment bytes. Freshly generated on each request and expires; do not cache it. Null if the stored file is no longer available.
40 |
# File 'lib/zavudev/models/message_list_attachments_response.rb', line 40 required :download_url, String, api_name: :downloadUrl, nil?: true |
#filename ⇒ String
45 |
# File 'lib/zavudev/models/message_list_attachments_response.rb', line 45 required :filename, String |
#id ⇒ String
20 |
# File 'lib/zavudev/models/message_list_attachments_response.rb', line 20 required :id, String |
#is_inline ⇒ Boolean
Whether the attachment is inline (embedded in the HTML body) rather than a regular attachment.
52 |
# File 'lib/zavudev/models/message_list_attachments_response.rb', line 52 required :is_inline, Zavudev::Internal::Type::Boolean, api_name: :isInline |
#mime_type ⇒ String
MIME type of the attachment.
58 |
# File 'lib/zavudev/models/message_list_attachments_response.rb', line 58 required :mime_type, String, api_name: :mimeType |
#size ⇒ Integer
Size of the attachment in bytes.
64 |
# File 'lib/zavudev/models/message_list_attachments_response.rb', line 64 required :size, Integer |
Instance Method Details
#to_hash ⇒ {
57 |
# File 'sig/zavudev/models/message_list_attachments_response.rbs', line 57
def to_hash: -> {
|