Class: Zavudev::Models::MessageSendParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::MessageSendParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/zavudev/models/message_send_params.rb
Overview
Defined Under Namespace
Classes: Attachment
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Zavudev::Models::MessageSendParams::Attachment>?
Email attachments.
-
#channel ⇒ Symbol, ...
Delivery channel.
-
#content ⇒ Zavudev::Models::MessageContent?
Additional content for non-text message types.
-
#fallback_enabled ⇒ Boolean?
Whether to enable automatic fallback to SMS if WhatsApp fails.
-
#html_body ⇒ String?
HTML body for email messages.
-
#idempotency_key ⇒ String?
Optional idempotency key to avoid duplicate sends.
-
#message_type ⇒ Symbol, ...
Type of message.
-
#metadata ⇒ Hash{Symbol=>String}?
Arbitrary metadata to associate with the message.
-
#reply_to ⇒ String?
Reply-To email address for email messages.
-
#subject ⇒ String?
Email subject line.
-
#text ⇒ String?
Text body for text messages or caption for media messages.
-
#to ⇒ String
Recipient phone number in E.164 format, email address, or numeric chat ID (for Telegram/Instagram).
-
#voice_language ⇒ String?
Language code for voice text-to-speech (e.g., ‘en-US’, ‘es-ES’, ‘pt-BR’).
- #zavu_sender ⇒ String?
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Zavudev::Internal::Type::BaseModel
Instance Attribute Details
#attachments ⇒ Array<Zavudev::Models::MessageSendParams::Attachment>?
Email attachments. Only supported when channel is ‘email’. Maximum 40MB total size.
22 |
# File 'lib/zavudev/models/message_send_params.rb', line 22 optional :attachments, -> { Zavudev::Internal::Type::ArrayOf[Zavudev::MessageSendParams::Attachment] } |
#channel ⇒ Symbol, ...
Delivery channel. Use ‘auto’ for intelligent routing. If omitted, channel is auto-selected based on sender capabilities and recipient type. For email recipients, defaults to ‘email’.
30 |
# File 'lib/zavudev/models/message_send_params.rb', line 30 optional :channel, enum: -> { Zavudev::Channel } |
#content ⇒ Zavudev::Models::MessageContent?
Additional content for non-text message types.
36 |
# File 'lib/zavudev/models/message_send_params.rb', line 36 optional :content, -> { Zavudev::MessageContent } |
#fallback_enabled ⇒ Boolean?
Whether to enable automatic fallback to SMS if WhatsApp fails. Defaults to true.
42 |
# File 'lib/zavudev/models/message_send_params.rb', line 42 optional :fallback_enabled, Zavudev::Internal::Type::Boolean, api_name: :fallbackEnabled |
#html_body ⇒ String?
HTML body for email messages. If provided, email will be sent as multipart with both text and HTML.
49 |
# File 'lib/zavudev/models/message_send_params.rb', line 49 optional :html_body, String, api_name: :htmlBody |
#idempotency_key ⇒ String?
Optional idempotency key to avoid duplicate sends.
55 |
# File 'lib/zavudev/models/message_send_params.rb', line 55 optional :idempotency_key, String, api_name: :idempotencyKey |
#message_type ⇒ Symbol, ...
Type of message. Defaults to ‘text’.
61 |
# File 'lib/zavudev/models/message_send_params.rb', line 61 optional :message_type, enum: -> { Zavudev::MessageType }, api_name: :messageType |
#metadata ⇒ Hash{Symbol=>String}?
Arbitrary metadata to associate with the message.
67 |
# File 'lib/zavudev/models/message_send_params.rb', line 67 optional :metadata, Zavudev::Internal::Type::HashOf[String] |
#reply_to ⇒ String?
Reply-To email address for email messages.
73 |
# File 'lib/zavudev/models/message_send_params.rb', line 73 optional :reply_to, String, api_name: :replyTo |
#subject ⇒ String?
Email subject line. Required when channel is ‘email’ or recipient is an email address.
80 |
# File 'lib/zavudev/models/message_send_params.rb', line 80 optional :subject, String |
#text ⇒ String?
Text body for text messages or caption for media messages.
86 |
# File 'lib/zavudev/models/message_send_params.rb', line 86 optional :text, String |
#to ⇒ String
Recipient phone number in E.164 format, email address, or numeric chat ID (for Telegram/Instagram).
15 |
# File 'lib/zavudev/models/message_send_params.rb', line 15 required :to, String |
#voice_language ⇒ String?
Language code for voice text-to-speech (e.g., ‘en-US’, ‘es-ES’, ‘pt-BR’). If omitted, language is auto-detected from recipient’s country code.
93 |
# File 'lib/zavudev/models/message_send_params.rb', line 93 optional :voice_language, String, api_name: :voiceLanguage |
#zavu_sender ⇒ String?
98 |
# File 'lib/zavudev/models/message_send_params.rb', line 98 optional :zavu_sender, String |