Class: Zavudev::Models::Sender
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::Sender
- Defined in:
- lib/zavudev/models/sender.rb,
sig/zavudev/models/sender.rbs
Overview
Defined Under Namespace
Classes: Whatsapp
Instance Attribute Summary collapse
- #created_at ⇒ Time?
-
#email_address ⇒ String?
From-address for the email channel, if configured.
-
#email_catch_all_enabled ⇒ Boolean?
Whether catch-all receiving is enabled.
-
#email_receiving_enabled ⇒ Boolean?
Whether inbound email receiving is enabled for this sender.
- #id ⇒ String
-
#is_default ⇒ Boolean?
Whether this sender is the project's default.
- #name ⇒ String
-
#phone_number ⇒ String
Phone number in E.164 format.
- #updated_at ⇒ Time?
-
#webhook ⇒ Zavudev::Models::SenderWebhook?
Webhook configuration for the sender.
-
#whatsapp ⇒ Zavudev::Models::Sender::Whatsapp?
WhatsApp Business Account information.
Instance Method Summary collapse
-
#initialize(id:, name:, phone_number:, created_at: nil, email_address: nil, email_catch_all_enabled: nil, email_receiving_enabled: nil, is_default: nil, updated_at: nil, webhook: nil, whatsapp: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Sender for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, phone_number:, created_at: nil, email_address: nil, email_catch_all_enabled: nil, email_receiving_enabled: nil, is_default: nil, updated_at: nil, webhook: nil, whatsapp: nil) ⇒ Object
Some parameter documentations has been truncated, see Zavudev::Models::Sender for more details.
|
|
# File 'lib/zavudev/models/sender.rb', line 72
|
Instance Attribute Details
#created_at ⇒ Time?
26 |
# File 'lib/zavudev/models/sender.rb', line 26 optional :created_at, Time, api_name: :createdAt |
#email_address ⇒ String?
From-address for the email channel, if configured.
32 |
# File 'lib/zavudev/models/sender.rb', line 32 optional :email_address, String, api_name: :emailAddress |
#email_catch_all_enabled ⇒ Boolean?
Whether catch-all receiving is enabled. When true (and emailReceivingEnabled is true), this sender receives email addressed to any local part at its domain, not just its own address. The original recipient is delivered in the message.inbound webhook's data.to.
41 |
# File 'lib/zavudev/models/sender.rb', line 41 optional :email_catch_all_enabled, Zavudev::Internal::Type::Boolean, api_name: :emailCatchAllEnabled |
#email_receiving_enabled ⇒ Boolean?
Whether inbound email receiving is enabled for this sender.
47 |
# File 'lib/zavudev/models/sender.rb', line 47 optional :email_receiving_enabled, Zavudev::Internal::Type::Boolean, api_name: :emailReceivingEnabled |
#id ⇒ String
10 |
# File 'lib/zavudev/models/sender.rb', line 10 required :id, String |
#is_default ⇒ Boolean?
Whether this sender is the project's default.
53 |
# File 'lib/zavudev/models/sender.rb', line 53 optional :is_default, Zavudev::Internal::Type::Boolean, api_name: :isDefault |
#name ⇒ String
15 |
# File 'lib/zavudev/models/sender.rb', line 15 required :name, String |
#phone_number ⇒ String
Phone number in E.164 format.
21 |
# File 'lib/zavudev/models/sender.rb', line 21 required :phone_number, String, api_name: :phoneNumber |
#updated_at ⇒ Time?
58 |
# File 'lib/zavudev/models/sender.rb', line 58 optional :updated_at, Time, api_name: :updatedAt |
#webhook ⇒ Zavudev::Models::SenderWebhook?
Webhook configuration for the sender.
64 |
# File 'lib/zavudev/models/sender.rb', line 64 optional :webhook, -> { Zavudev::SenderWebhook } |
#whatsapp ⇒ Zavudev::Models::Sender::Whatsapp?
WhatsApp Business Account information. Only present if a WABA is connected.
70 |
# File 'lib/zavudev/models/sender.rb', line 70 optional :whatsapp, -> { Zavudev::Sender::Whatsapp } |
Instance Method Details
#to_hash ⇒ {
71 |
# File 'sig/zavudev/models/sender.rbs', line 71
def to_hash: -> {
|