Class: Zavudev::Models::Sender
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::Sender
- Defined in:
- lib/zavudev/models/sender.rb
Overview
Defined Under Namespace
Classes: Whatsapp
Instance Attribute Summary collapse
- #created_at ⇒ Time?
-
#email_receiving_enabled ⇒ Boolean?
Whether inbound email receiving is enabled for this sender.
- #id ⇒ String
-
#is_default ⇒ Boolean?
Whether this sender is the project’s default.
- #name ⇒ String
-
#phone_number ⇒ String
Phone number in E.164 format.
- #updated_at ⇒ Time?
-
#webhook ⇒ Zavudev::Models::SenderWebhook?
Webhook configuration for the sender.
-
#whatsapp ⇒ Zavudev::Models::Sender::Whatsapp?
WhatsApp Business Account information.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, phone_number:, created_at: nil, email_receiving_enabled: nil, is_default: nil, updated_at: nil, webhook: nil, whatsapp: nil) ⇒ Object
|
|
# File 'lib/zavudev/models/sender.rb', line 57
|
Instance Attribute Details
#created_at ⇒ Time?
26 |
# File 'lib/zavudev/models/sender.rb', line 26 optional :created_at, Time, api_name: :createdAt |
#email_receiving_enabled ⇒ Boolean?
Whether inbound email receiving is enabled for this sender.
32 |
# File 'lib/zavudev/models/sender.rb', line 32 optional :email_receiving_enabled, Zavudev::Internal::Type::Boolean, api_name: :emailReceivingEnabled |
#id ⇒ String
10 |
# File 'lib/zavudev/models/sender.rb', line 10 required :id, String |
#is_default ⇒ Boolean?
Whether this sender is the project’s default.
38 |
# File 'lib/zavudev/models/sender.rb', line 38 optional :is_default, Zavudev::Internal::Type::Boolean, api_name: :isDefault |
#name ⇒ String
15 |
# File 'lib/zavudev/models/sender.rb', line 15 required :name, String |
#phone_number ⇒ String
Phone number in E.164 format.
21 |
# File 'lib/zavudev/models/sender.rb', line 21 required :phone_number, String, api_name: :phoneNumber |
#updated_at ⇒ Time?
43 |
# File 'lib/zavudev/models/sender.rb', line 43 optional :updated_at, Time, api_name: :updatedAt |
#webhook ⇒ Zavudev::Models::SenderWebhook?
Webhook configuration for the sender.
49 |
# File 'lib/zavudev/models/sender.rb', line 49 optional :webhook, -> { Zavudev::SenderWebhook } |
#whatsapp ⇒ Zavudev::Models::Sender::Whatsapp?
WhatsApp Business Account information. Only present if a WABA is connected.
55 |
# File 'lib/zavudev/models/sender.rb', line 55 optional :whatsapp, -> { Zavudev::Sender::Whatsapp } |