Class: Zavudev::Models::SenderCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::SenderCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/zavudev/models/sender_create_params.rb,
sig/zavudev/models/sender_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#email_address ⇒ String?
From-address for the email channel (e.g. noreply@yourdomain.com).
-
#email_domain_id ⇒ String?
ID of the verified email domain to attach.
-
#email_from_name ⇒ String?
Display name shown in the recipient's inbox for the email channel.
-
#email_receiving_enabled ⇒ Boolean?
Enable inbound email receiving on this sender.
- #name ⇒ String
-
#phone_number ⇒ String?
Phone number in E.164 format.
- #set_as_default ⇒ Boolean?
-
#webhook_events ⇒ Array<Symbol, Zavudev::Models::WebhookEvent>?
Events to subscribe to.
-
#webhook_url ⇒ String?
HTTPS URL for webhook events.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(name:, email_address: nil, email_domain_id: nil, email_from_name: nil, email_receiving_enabled: nil, phone_number: nil, set_as_default: nil, webhook_events: nil, webhook_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SenderCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, email_address: nil, email_domain_id: nil, email_from_name: nil, email_receiving_enabled: nil, phone_number: nil, set_as_default: nil, webhook_events: nil, webhook_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Zavudev::Models::SenderCreateParams for more details.
|
|
# File 'lib/zavudev/models/sender_create_params.rb', line 69
|
Instance Attribute Details
#email_address ⇒ String?
From-address for the email channel (e.g. noreply@yourdomain.com). The address's domain must be a verified email domain in your project. Setting this attaches the email channel to the sender.
21 |
# File 'lib/zavudev/models/sender_create_params.rb', line 21 optional :email_address, String, api_name: :emailAddress |
#email_domain_id ⇒ String?
ID of the verified email domain to attach. Optional — resolved from
emailAddress's domain when omitted.
28 |
# File 'lib/zavudev/models/sender_create_params.rb', line 28 optional :email_domain_id, String, api_name: :emailDomainId |
#email_from_name ⇒ String?
Display name shown in the recipient's inbox for the email channel.
34 |
# File 'lib/zavudev/models/sender_create_params.rb', line 34 optional :email_from_name, String, api_name: :emailFromName |
#email_receiving_enabled ⇒ Boolean?
Enable inbound email receiving on this sender. Requires a verified MX record on the domain; ignored otherwise.
41 |
# File 'lib/zavudev/models/sender_create_params.rb', line 41 optional :email_receiving_enabled, Zavudev::Internal::Type::Boolean, api_name: :emailReceivingEnabled |
#name ⇒ String
13 |
# File 'lib/zavudev/models/sender_create_params.rb', line 13 required :name, String |
#phone_number ⇒ String?
Phone number in E.164 format. Required for phone-based channels (SMS, WhatsApp). Omit for an email-only sender.
48 |
# File 'lib/zavudev/models/sender_create_params.rb', line 48 optional :phone_number, String, api_name: :phoneNumber |
#set_as_default ⇒ Boolean?
53 |
# File 'lib/zavudev/models/sender_create_params.rb', line 53 optional :set_as_default, Zavudev::Internal::Type::Boolean, api_name: :setAsDefault |
#webhook_events ⇒ Array<Symbol, Zavudev::Models::WebhookEvent>?
Events to subscribe to.
59 60 61 |
# File 'lib/zavudev/models/sender_create_params.rb', line 59 optional :webhook_events, -> { Zavudev::Internal::Type::ArrayOf[enum: Zavudev::WebhookEvent] }, api_name: :webhookEvents |
#webhook_url ⇒ String?
HTTPS URL for webhook events.
67 |
# File 'lib/zavudev/models/sender_create_params.rb', line 67 optional :webhook_url, String, api_name: :webhookUrl |
Instance Method Details
#to_hash ⇒ {
70 |
# File 'sig/zavudev/models/sender_create_params.rbs', line 70
def to_hash: -> {
|