Class: Zavudev::Models::SenderUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/zavudev/models/sender_update_params.rb,
sig/zavudev/models/sender_update_params.rbs

Overview

See Also:

  • Zavudev::Resources::Senders#update

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(sender_id:, email_address: nil, email_catch_all_enabled: nil, email_domain_id: nil, email_from_name: nil, email_receiving_enabled: nil, name: nil, set_as_default: nil, webhook_active: nil, webhook_events: nil, webhook_url: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Zavudev::Models::SenderUpdateParams for more details.

Parameters:

  • sender_id (String)
  • email_address (String) (defaults to: nil)

    Attach or change the sender's email from-address (e.g. noreply@yourdomain.com).

  • email_catch_all_enabled (Boolean) (defaults to: nil)

    Enable or disable domain catch-all. When enabled (with emailReceivingEnabled tru

  • email_domain_id (String) (defaults to: nil)

    ID of the verified email domain to attach. Optional — resolved from `emailAddres

  • email_from_name (String) (defaults to: nil)

    Display name shown in the recipient's inbox for the email channel.

  • email_receiving_enabled (Boolean) (defaults to: nil)

    Enable or disable inbound email receiving for this sender.

  • name (String) (defaults to: nil)
  • set_as_default (Boolean) (defaults to: nil)
  • webhook_active (Boolean) (defaults to: nil)

    Whether the webhook is active.

  • webhook_events (Array<Symbol, Zavudev::Models::WebhookEvent>) (defaults to: nil)

    Events to subscribe to.

  • webhook_url (String, nil) (defaults to: nil)

    HTTPS URL for webhook events. Set to null to remove webhook.

  • request_options (Zavudev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/zavudev/models/sender_update_params.rb', line 79

Instance Attribute Details

#email_addressString?

Attach or change the sender's email from-address (e.g. noreply@yourdomain.com). The domain must be a verified email domain in your project.

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/zavudev/models/sender_update_params.rb', line 20

optional :email_address, String, api_name: :emailAddress

#email_catch_all_enabledBoolean?

Enable or disable domain catch-all. When enabled (with emailReceivingEnabled true), this sender receives email for any address at its domain. Ignored (treated as false) if receiving is not enabled.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


28
# File 'lib/zavudev/models/sender_update_params.rb', line 28

optional :email_catch_all_enabled, Zavudev::Internal::Type::Boolean, api_name: :emailCatchAllEnabled

#email_domain_idString?

ID of the verified email domain to attach. Optional — resolved from emailAddress's domain when omitted.

Parameters:

  • (String)

Returns:

  • (String, nil)


35
# File 'lib/zavudev/models/sender_update_params.rb', line 35

optional :email_domain_id, String, api_name: :emailDomainId

#email_from_nameString?

Display name shown in the recipient's inbox for the email channel.

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/zavudev/models/sender_update_params.rb', line 41

optional :email_from_name, String, api_name: :emailFromName

#email_receiving_enabledBoolean?

Enable or disable inbound email receiving for this sender.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


47
# File 'lib/zavudev/models/sender_update_params.rb', line 47

optional :email_receiving_enabled, Zavudev::Internal::Type::Boolean, api_name: :emailReceivingEnabled

#nameString?

Parameters:

  • (String)

Returns:

  • (String, nil)


52
# File 'lib/zavudev/models/sender_update_params.rb', line 52

optional :name, String

#sender_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/zavudev/models/sender_update_params.rb', line 13

required :sender_id, String

#set_as_defaultBoolean?

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


57
# File 'lib/zavudev/models/sender_update_params.rb', line 57

optional :set_as_default, Zavudev::Internal::Type::Boolean, api_name: :setAsDefault

#webhook_activeBoolean?

Whether the webhook is active.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


63
# File 'lib/zavudev/models/sender_update_params.rb', line 63

optional :webhook_active, Zavudev::Internal::Type::Boolean, api_name: :webhookActive

#webhook_eventsArray<Symbol, Zavudev::Models::WebhookEvent>?

Events to subscribe to.

Returns:



69
70
71
# File 'lib/zavudev/models/sender_update_params.rb', line 69

optional :webhook_events,
-> { Zavudev::Internal::Type::ArrayOf[enum: Zavudev::WebhookEvent] },
api_name: :webhookEvents

#webhook_urlString?

HTTPS URL for webhook events. Set to null to remove webhook.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


77
# File 'lib/zavudev/models/sender_update_params.rb', line 77

optional :webhook_url, String, api_name: :webhookUrl, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


80
# File 'sig/zavudev/models/sender_update_params.rbs', line 80

def to_hash: -> {