Class: Zavudev::Models::SenderUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Zavudev::Models::SenderUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/zavudev/models/sender_update_params.rb,
sig/zavudev/models/sender_update_params.rbs
Overview
Instance Attribute Summary collapse
-
#email_address ⇒ String?
Attach or change the sender's email from-address (e.g. noreply@yourdomain.com).
-
#email_catch_all_enabled ⇒ Boolean?
Enable or disable domain catch-all.
-
#email_domain_id ⇒ String?
ID of the verified email domain to attach.
-
#email_from_name ⇒ String?
Display name shown in the recipient's inbox for the email channel.
-
#email_receiving_enabled ⇒ Boolean?
Enable or disable inbound email receiving for this sender.
- #name ⇒ String?
- #sender_id ⇒ String
- #set_as_default ⇒ Boolean?
-
#webhook_active ⇒ Boolean?
Whether the webhook is active.
-
#webhook_events ⇒ Array<Symbol, Zavudev::Models::WebhookEvent>?
Events to subscribe to.
-
#webhook_url ⇒ String?
HTTPS URL for webhook events.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(sender_id:, email_address: nil, email_catch_all_enabled: nil, email_domain_id: nil, email_from_name: nil, email_receiving_enabled: nil, name: nil, set_as_default: nil, webhook_active: nil, webhook_events: nil, webhook_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SenderUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(sender_id:, email_address: nil, email_catch_all_enabled: nil, email_domain_id: nil, email_from_name: nil, email_receiving_enabled: nil, name: nil, set_as_default: nil, webhook_active: nil, webhook_events: nil, webhook_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Zavudev::Models::SenderUpdateParams for more details.
|
|
# File 'lib/zavudev/models/sender_update_params.rb', line 79
|
Instance Attribute Details
#email_address ⇒ String?
Attach or change the sender's email from-address (e.g. noreply@yourdomain.com). The domain must be a verified email domain in your project.
20 |
# File 'lib/zavudev/models/sender_update_params.rb', line 20 optional :email_address, String, api_name: :emailAddress |
#email_catch_all_enabled ⇒ Boolean?
Enable or disable domain catch-all. When enabled (with emailReceivingEnabled true), this sender receives email for any address at its domain. Ignored (treated as false) if receiving is not enabled.
28 |
# File 'lib/zavudev/models/sender_update_params.rb', line 28 optional :email_catch_all_enabled, Zavudev::Internal::Type::Boolean, api_name: :emailCatchAllEnabled |
#email_domain_id ⇒ String?
ID of the verified email domain to attach. Optional — resolved from
emailAddress's domain when omitted.
35 |
# File 'lib/zavudev/models/sender_update_params.rb', line 35 optional :email_domain_id, String, api_name: :emailDomainId |
#email_from_name ⇒ String?
Display name shown in the recipient's inbox for the email channel.
41 |
# File 'lib/zavudev/models/sender_update_params.rb', line 41 optional :email_from_name, String, api_name: :emailFromName |
#email_receiving_enabled ⇒ Boolean?
Enable or disable inbound email receiving for this sender.
47 |
# File 'lib/zavudev/models/sender_update_params.rb', line 47 optional :email_receiving_enabled, Zavudev::Internal::Type::Boolean, api_name: :emailReceivingEnabled |
#name ⇒ String?
52 |
# File 'lib/zavudev/models/sender_update_params.rb', line 52 optional :name, String |
#sender_id ⇒ String
13 |
# File 'lib/zavudev/models/sender_update_params.rb', line 13 required :sender_id, String |
#set_as_default ⇒ Boolean?
57 |
# File 'lib/zavudev/models/sender_update_params.rb', line 57 optional :set_as_default, Zavudev::Internal::Type::Boolean, api_name: :setAsDefault |
#webhook_active ⇒ Boolean?
Whether the webhook is active.
63 |
# File 'lib/zavudev/models/sender_update_params.rb', line 63 optional :webhook_active, Zavudev::Internal::Type::Boolean, api_name: :webhookActive |
#webhook_events ⇒ Array<Symbol, Zavudev::Models::WebhookEvent>?
Events to subscribe to.
69 70 71 |
# File 'lib/zavudev/models/sender_update_params.rb', line 69 optional :webhook_events, -> { Zavudev::Internal::Type::ArrayOf[enum: Zavudev::WebhookEvent] }, api_name: :webhookEvents |
#webhook_url ⇒ String?
HTTPS URL for webhook events. Set to null to remove webhook.
77 |
# File 'lib/zavudev/models/sender_update_params.rb', line 77 optional :webhook_url, String, api_name: :webhookUrl, nil?: true |
Instance Method Details
#to_hash ⇒ {
80 |
# File 'sig/zavudev/models/sender_update_params.rbs', line 80
def to_hash: -> {
|