Class: Zavudev::Models::SenderUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/zavudev/models/sender_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(sender_id:, email_receiving_enabled: nil, name: nil, set_as_default: nil, webhook_active: nil, webhook_events: nil, webhook_url: nil, request_options: {}) ⇒ Object

Parameters:

  • sender_id (String)
  • email_receiving_enabled (Boolean) (defaults to: nil)

    Enable or disable inbound email receiving for this sender.

  • name (String) (defaults to: nil)
  • set_as_default (Boolean) (defaults to: nil)
  • webhook_active (Boolean) (defaults to: nil)

    Whether the webhook is active.

  • webhook_events (Array<Symbol, Zavudev::Models::WebhookEvent>) (defaults to: nil)

    Events to subscribe to.

  • webhook_url (String, nil) (defaults to: nil)

    HTTPS URL for webhook events. Set to null to remove webhook.

  • request_options (Zavudev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/zavudev/models/sender_update_params.rb', line 51

Instance Attribute Details

#email_receiving_enabledBoolean?

Enable or disable inbound email receiving for this sender.

Returns:

  • (Boolean, nil)


19
# File 'lib/zavudev/models/sender_update_params.rb', line 19

optional :email_receiving_enabled, Zavudev::Internal::Type::Boolean, api_name: :emailReceivingEnabled

#nameString?

Returns:

  • (String, nil)


24
# File 'lib/zavudev/models/sender_update_params.rb', line 24

optional :name, String

#sender_idString

Returns:

  • (String)


13
# File 'lib/zavudev/models/sender_update_params.rb', line 13

required :sender_id, String

#set_as_defaultBoolean?

Returns:

  • (Boolean, nil)


29
# File 'lib/zavudev/models/sender_update_params.rb', line 29

optional :set_as_default, Zavudev::Internal::Type::Boolean, api_name: :setAsDefault

#webhook_activeBoolean?

Whether the webhook is active.

Returns:

  • (Boolean, nil)


35
# File 'lib/zavudev/models/sender_update_params.rb', line 35

optional :webhook_active, Zavudev::Internal::Type::Boolean, api_name: :webhookActive

#webhook_eventsArray<Symbol, Zavudev::Models::WebhookEvent>?

Events to subscribe to.

Returns:



41
42
43
# File 'lib/zavudev/models/sender_update_params.rb', line 41

optional :webhook_events,
-> { Zavudev::Internal::Type::ArrayOf[enum: Zavudev::WebhookEvent] },
api_name: :webhookEvents

#webhook_urlString?

HTTPS URL for webhook events. Set to null to remove webhook.

Returns:

  • (String, nil)


49
# File 'lib/zavudev/models/sender_update_params.rb', line 49

optional :webhook_url, String, api_name: :webhookUrl, nil?: true