Class: Zavudev::Resources::Senders

Inherits:
Object
  • Object
show all
Defined in:
lib/zavudev/resources/senders.rb,
lib/zavudev/resources/senders/agent.rb,
lib/zavudev/resources/senders/agent/flows.rb,
lib/zavudev/resources/senders/agent/tools.rb,
lib/zavudev/resources/senders/agent/executions.rb,
lib/zavudev/resources/senders/agent/knowledge_bases.rb,
lib/zavudev/resources/senders/agent/knowledge_bases/documents.rb

Defined Under Namespace

Classes: Agent

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Senders

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Senders.

Parameters:



240
241
242
243
# File 'lib/zavudev/resources/senders.rb', line 240

def initialize(client:)
  @client = client
  @agent = Zavudev::Resources::Senders::Agent.new(client: client)
end

Instance Attribute Details

#agentZavudev::Resources::Senders::Agent (readonly)



7
8
9
# File 'lib/zavudev/resources/senders.rb', line 7

def agent
  @agent
end

Instance Method Details

#create(name:, phone_number:, set_as_default: nil, webhook_events: nil, webhook_url: nil, request_options: {}) ⇒ Zavudev::Models::Sender

Create sender

Parameters:

  • name (String)
  • phone_number (String)
  • set_as_default (Boolean)
  • webhook_events (Array<Symbol, Zavudev::Models::WebhookEvent>)

    Events to subscribe to.

  • webhook_url (String)

    HTTPS URL for webhook events.

  • request_options (Zavudev::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



28
29
30
31
32
33
34
35
36
37
# File 'lib/zavudev/resources/senders.rb', line 28

def create(params)
  parsed, options = Zavudev::SenderCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "v1/senders",
    body: parsed,
    model: Zavudev::Sender,
    options: options
  )
end

#delete(sender_id, request_options: {}) ⇒ nil

Delete sender

Parameters:

Returns:

  • (nil)

See Also:



126
127
128
129
130
131
132
133
# File 'lib/zavudev/resources/senders.rb', line 126

def delete(sender_id, params = {})
  @client.request(
    method: :delete,
    path: ["v1/senders/%1$s", sender_id],
    model: NilClass,
    options: params[:request_options]
  )
end

#get_profile(sender_id, request_options: {}) ⇒ Zavudev::Models::WhatsappBusinessProfileResponse

Get the WhatsApp Business profile for a sender. The sender must have a WhatsApp Business Account connected.

Parameters:

Returns:

See Also:



146
147
148
149
150
151
152
153
# File 'lib/zavudev/resources/senders.rb', line 146

def get_profile(sender_id, params = {})
  @client.request(
    method: :get,
    path: ["v1/senders/%1$s/profile", sender_id],
    model: Zavudev::WhatsappBusinessProfileResponse,
    options: params[:request_options]
  )
end

#list(cursor: nil, limit: nil, request_options: {}) ⇒ Zavudev::Internal::Cursor<Zavudev::Models::Sender>

List senders

Parameters:

Returns:

See Also:



103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/zavudev/resources/senders.rb', line 103

def list(params = {})
  parsed, options = Zavudev::SenderListParams.dump_request(params)
  query = Zavudev::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "v1/senders",
    query: query,
    page: Zavudev::Internal::Cursor,
    model: Zavudev::Sender,
    options: options
  )
end

#regenerate_webhook_secret(sender_id, request_options: {}) ⇒ Zavudev::Models::WebhookSecretResponse

Regenerate the webhook secret for a sender. The old secret will be invalidated immediately.

Parameters:

Returns:

See Also:



166
167
168
169
170
171
172
173
# File 'lib/zavudev/resources/senders.rb', line 166

def regenerate_webhook_secret(sender_id, params = {})
  @client.request(
    method: :post,
    path: ["v1/senders/%1$s/webhook/secret", sender_id],
    model: Zavudev::WebhookSecretResponse,
    options: params[:request_options]
  )
end

#retrieve(sender_id, request_options: {}) ⇒ Zavudev::Models::Sender

Get sender

Parameters:

Returns:

See Also:



49
50
51
52
53
54
55
56
# File 'lib/zavudev/resources/senders.rb', line 49

def retrieve(sender_id, params = {})
  @client.request(
    method: :get,
    path: ["v1/senders/%1$s", sender_id],
    model: Zavudev::Sender,
    options: params[:request_options]
  )
end

#update(sender_id, email_receiving_enabled: nil, name: nil, set_as_default: nil, webhook_active: nil, webhook_events: nil, webhook_url: nil, request_options: {}) ⇒ Zavudev::Models::Sender

Update sender

Parameters:

  • sender_id (String)
  • email_receiving_enabled (Boolean)

    Enable or disable inbound email receiving for this sender.

  • name (String)
  • set_as_default (Boolean)
  • webhook_active (Boolean)

    Whether the webhook is active.

  • webhook_events (Array<Symbol, Zavudev::Models::WebhookEvent>)

    Events to subscribe to.

  • webhook_url (String, nil)

    HTTPS URL for webhook events. Set to null to remove webhook.

  • request_options (Zavudev::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



81
82
83
84
85
86
87
88
89
90
# File 'lib/zavudev/resources/senders.rb', line 81

def update(sender_id, params = {})
  parsed, options = Zavudev::SenderUpdateParams.dump_request(params)
  @client.request(
    method: :patch,
    path: ["v1/senders/%1$s", sender_id],
    body: parsed,
    model: Zavudev::Sender,
    options: options
  )
end

#update_profile(sender_id, about: nil, address: nil, description: nil, email: nil, vertical: nil, websites: nil, request_options: {}) ⇒ Zavudev::Models::SenderUpdateProfileResponse

Update the WhatsApp Business profile for a sender. The sender must have a WhatsApp Business Account connected.

Parameters:

  • sender_id (String)
  • about (String)

    Short description of the business (max 139 characters).

  • address (String)

    Physical address of the business (max 256 characters).

  • description (String)

    Extended description of the business (max 512 characters).

  • email (String)

    Business email address.

  • vertical (Symbol, Zavudev::Models::WhatsappBusinessProfileVertical)

    Business category for WhatsApp Business profile.

  • websites (Array<String>)

    Business website URLs (maximum 2).

  • request_options (Zavudev::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



199
200
201
202
203
204
205
206
207
208
# File 'lib/zavudev/resources/senders.rb', line 199

def update_profile(sender_id, params = {})
  parsed, options = Zavudev::SenderUpdateProfileParams.dump_request(params)
  @client.request(
    method: :patch,
    path: ["v1/senders/%1$s/profile", sender_id],
    body: parsed,
    model: Zavudev::Models::SenderUpdateProfileResponse,
    options: options
  )
end

#upload_profile_picture(sender_id, image_url:, mime_type:, request_options: {}) ⇒ Zavudev::Models::SenderUploadProfilePictureResponse

Upload a new profile picture for the WhatsApp Business profile. The image will be uploaded to Meta and set as the profile picture.

Parameters:

Returns:

See Also:



226
227
228
229
230
231
232
233
234
235
# File 'lib/zavudev/resources/senders.rb', line 226

def upload_profile_picture(sender_id, params)
  parsed, options = Zavudev::SenderUploadProfilePictureParams.dump_request(params)
  @client.request(
    method: :post,
    path: ["v1/senders/%1$s/profile/picture", sender_id],
    body: parsed,
    model: Zavudev::Models::SenderUploadProfilePictureResponse,
    options: options
  )
end